PrinterInfo class

Available extensions
Annotations
  • @HybridRecord.new()

Constructors

PrinterInfo({required String id, required String name, String address = '', bool isDefault = false, bool isAvailable = true})

Properties

address String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
isAvailable bool
final
isDefault bool
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeFields(RecordWriterBase writer) → void

Available on PrinterInfo, provided by the PrinterInfoRecordExt extension

Operators

operator ==(Object other) bool
The equality operator.
inherited